<?php

namespace AppDraply\Admin;

use AppDraply\Admin\Utils\Field;
use AppDraply\Admin\Utils\Section;
use AppDraply\Config;
use AppDraply\Traits\Webhook;

class Settings
{
	use Webhook;

	/**
	 * 0 		: 	disconnected
	 * 1 		:		connected
	 */
	private $is_connected = 0;

	public function register()
	{
		// Set is_connected to a boolean value so that we don't make requests during development
		if (! Config::get('check_store_connection')) {
			$this->is_connected = false;
		}

		add_action('admin_menu', [$this, 'add_admin_menu']);
		add_action('admin_enqueue_scripts', [$this, 'enqueue_assets']);
	}

	public function add_admin_menu()
	{
		$response = wp_remote_get(Config::get('plugin_url') . '/assets/img/logo-symbol.svg');
		if (is_wp_error($response)) {
			$svg = '';
		} else {
			$svg = wp_remote_retrieve_body($response);
		}

		add_menu_page(Config::$APP_NAME, Config::$APP_NAME, 'manage_options', DRAPLY_PLUGIN_SLUG, [$this, 'load_template'], 'data:image/svg+xml;base64,' . base64_encode($svg));
	}

	public function load_template()
	{
		include Config::get('plugin_path') . 'views/admin/pages/settings.php';
	}

	public function is_connected(): bool
	{
		$this->is_connected = intval(get_option(Config::$OPTION_IS_CONNECTED, 0));

		return !!$this->is_connected;
	}

	public function enqueue_assets($hook)
	{
		$current_page = $hook;
		$expected_page = 'toplevel_page_' . DRAPLY_PLUGIN_SLUG; // 假设你的插件页面是顶级页面

		if ($current_page !== $expected_page) {
			return;
		}

		$handle    = DRAPLY_PLUGIN_SLUG . '-admin';
		$css_path  = 'assets/dist/css/admin.css';
		$js_path   = 'assets/dist/js/admin.js';
		$css_mtime = filemtime(Config::get('plugin_path') . $css_path);
		$js_mtime  = filemtime(Config::get('plugin_path') . $js_path);

		wp_register_style($handle, Config::get('plugin_url') . $css_path, [], $css_mtime, 'screen');
		wp_register_script($handle, Config::get('plugin_url') . $js_path, [], $js_mtime, true);

		wp_enqueue_style($handle);
		wp_enqueue_script($handle);
	}
}
